#!/usr/bin/env python
# Copyright:
# ----------------------------------------------------------------------------
# This confidential and proprietary software may be used only as authorized
# by a licensing agreement from ARM Limited.
#      (C) COPYRIGHT 2019-2020 ARM Limited, ALL RIGHTS RESERVED
# The entire notice above must be reproduced on all authorized copies and
# copies may only be made to the extent permitted by a licensing agreement
# from ARM Limited.
# ----------------------------------------------------------------------------
#

import logging
import os
import subprocess
import sys


logger = logging.getLogger(__name__)


def get_platform_version():
    android_build_top = os.getenv("ANDROID_BUILD_TOP")
    if android_build_top is None:
        logger.error("ANDROID_BUILD_TOP not set")
        return None

    soong_ui = os.path.join(android_build_top, "build", "soong", "soong_ui.bash")
    try:
        cmd = [soong_ui, "--dumpvar-mode", "PLATFORM_VERSION"]
        # Ignore soong_ui's stderr output by redirecting it. This does not end
        # up in the captured output.
        platform_version = subprocess.check_output(cmd,
                                                   stderr=subprocess.PIPE).decode().strip()
    except (OSError, subprocess.CalledProcessError) as e:
        logger.error("%s", str(e))
        return None

    if platform_version.isalpha():
        # Early access versions and aosp master have a single letter for PLATFORM_VERSION eg. 'Q' for Android 10
        platform_version = ord(platform_version) - 71
    return int(platform_version)


if __name__ == "__main__":
    logging.basicConfig()

    version = get_platform_version()
    if version is not None:
        sys.stdout.write(str(version) + "\n")
    else:
        sys.stderr.write("Could not get Android version\n")
        sys.exit(1)
